@@ -7,9 +7,9 @@ use educe::Educe;
 
 /// A type should satisfy this trait to be a dependency property type,
 /// a dependency vector item type, or a flow data type.
-pub trait Convenient: PartialEq + Clone + Debug + Send + Sync + 'static { }
+pub trait Convenient: PartialEq + Clone + Debug + 'static { }
 
-impl<T: PartialEq + Clone + Debug + Send + Sync + 'static> Convenient for T { }
+impl<T: PartialEq + Clone + Debug + 'static> Convenient for T { }
 
 pub struct GlobDescriptor<Obj> {
     pub arena: TypeId,
